# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CoinIdEnum(object):

    """Implementation of the 'coin_id' enum.

    Attributes:
        BITCOIN: The enum member of type str.
        ETHEREUM: The enum member of type str.

    """
    BITCOIN = 'bitcoin'

    ETHEREUM = 'ethereum'

