# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class IncludeTickersEnum(object):

    """Implementation of the 'include_tickers' enum.

    Attributes:
        ALL: The enum member of type str.
        UNEXPIRED: The enum member of type str.

    """
    ALL = 'all'

    UNEXPIRED = 'unexpired'

