# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Order2Enum(object):

    """Implementation of the 'order2' enum.

    Attributes:
        MARKET_CAP_DESC: The enum member of type str.
        MARKET_CAP_ASC: The enum member of type str.
        NAME_DESC: The enum member of type str.
        NAME_ASC: The enum member of type str.
        MARKET_CAP_CHANGE_24H_DESC: The enum member of type str.
        MARKET_CAP_CHANGE_24H_ASC: The enum member of type str.

    """
    MARKET_CAP_DESC = 'market_cap_desc'

    MARKET_CAP_ASC = 'market_cap_asc'

    NAME_DESC = 'name_desc'

    NAME_ASC = 'name_asc'

    MARKET_CAP_CHANGE_24H_DESC = 'market_cap_change_24h_desc'

    MARKET_CAP_CHANGE_24H_ASC = 'market_cap_change_24h_asc'

