# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StatusEnum(object):

    """Implementation of the 'status' enum.

    Attributes:
        ACTIVE: The enum member of type str.
        INACTIVE: The enum member of type str.

    """
    ACTIVE = 'active'

    INACTIVE = 'inactive'

