# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Order1Enum(object):

    """Implementation of the 'order1' enum.

    Attributes:
        TRUST_SCORE_DESC: The enum member of type str.
        TRUST_SCORE_ASC: The enum member of type str.
        VOLUME_DESC: The enum member of type str.
        VOLUME_ASC: The enum member of type str.

    """
    TRUST_SCORE_DESC = 'trust_score_desc'

    TRUST_SCORE_ASC = 'trust_score_asc'

    VOLUME_DESC = 'volume_desc'

    VOLUME_ASC = 'volume_asc'

