# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class LocaleEnum(object):

    """Implementation of the 'locale' enum.

    Attributes:
        AR: The enum member of type str.
        BG: The enum member of type str.
        CS: The enum member of type str.
        DA: The enum member of type str.
        DE: The enum member of type str.
        EL: The enum member of type str.
        EN: The enum member of type str.
        ES: The enum member of type str.
        FI: The enum member of type str.
        FR: The enum member of type str.
        HE: The enum member of type str.
        HI: The enum member of type str.
        HR: The enum member of type str.
        HU: The enum member of type str.
        ID: The enum member of type str.
        IT: The enum member of type str.
        JA: The enum member of type str.
        KO: The enum member of type str.
        LT: The enum member of type str.
        NL: The enum member of type str.
        NO: The enum member of type str.
        PL: The enum member of type str.
        PT: The enum member of type str.
        RO: The enum member of type str.
        RU: The enum member of type str.
        SK: The enum member of type str.
        SL: The enum member of type str.
        SV: The enum member of type str.
        TH: The enum member of type str.
        TR: The enum member of type str.
        UK: The enum member of type str.
        VI: The enum member of type str.
        ZH: The enum member of type str.
        ZHTW: The enum member of type str.

    """
    AR = 'ar'

    BG = 'bg'

    CS = 'cs'

    DA = 'da'

    DE = 'de'

    EL = 'el'

    EN = 'en'

    ES = 'es'

    FI = 'fi'

    FR = 'fr'

    HE = 'he'

    HI = 'hi'

    HR = 'hr'

    HU = 'hu'

    ID = 'id'

    IT = 'it'

    JA = 'ja'

    KO = 'ko'

    LT = 'lt'

    NL = 'nl'

    NO = 'no'

    PL = 'pl'

    PT = 'pt'

    RO = 'ro'

    RU = 'ru'

    SK = 'sk'

    SL = 'sl'

    SV = 'sv'

    TH = 'th'

    TR = 'tr'

    UK = 'uk'

    VI = 'vi'

    ZH = 'zh'

    ZHTW = 'zh-tw'

