# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class IntervalEnum(object):

    """Implementation of the 'interval' enum.

    Attributes:
        DAILY: The enum member of type str.

    """
    DAILY = 'daily'

