# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Order4Enum(object):

    """Implementation of the 'order4' enum.

    Attributes:
        NAME_ASC: The enum member of type str.
        NAME_DESC: The enum member of type str.
        OPEN_INTEREST_BTC_ASC: The enum member of type str.
        OPEN_INTEREST_BTC_DESC: The enum member of type str.
        TRADE_VOLUME_24H_BTC_ASC: The enum member of type str.
        TRADE_VOLUME_24H_BTC_DESC: The enum member of type str.

    """
    NAME_ASC = 'name_asc'

    NAME_DESC = 'name_desc'

    OPEN_INTEREST_BTC_ASC = 'open_interest_btc_asc'

    OPEN_INTEREST_BTC_DESC = 'open_interest_btc_desc'

    TRADE_VOLUME_24H_BTC_ASC = 'trade_volume_24h_btc_asc'

    TRADE_VOLUME_24H_BTC_DESC = 'trade_volume_24h_btc_desc'

