# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Order5Enum(object):

    """Implementation of the 'order5' enum.

    Attributes:
        H24_VOLUME_USD_ASC: The enum member of type str.
        H24_VOLUME_USD_DESC: The enum member of type str.
        H24_VOLUME_NATIVE_ASC: The enum member of type str.
        H24_VOLUME_NATIVE_DESC: The enum member of type str.
        FLOOR_PRICE_NATIVE_ASC: The enum member of type str.
        FLOOR_PRICE_NATIVE_DESC: The enum member of type str.
        MARKET_CAP_NATIVE_ASC: The enum member of type str.
        MARKET_CAP_NATIVE_DESC: The enum member of type str.
        MARKET_CAP_USD_ASC: The enum member of type str.
        MARKET_CAP_USD_DESC: The enum member of type str.

    """
    H24_VOLUME_USD_ASC = 'h24_volume_usd_asc'

    H24_VOLUME_USD_DESC = 'h24_volume_usd_desc'

    H24_VOLUME_NATIVE_ASC = 'h24_volume_native_asc'

    H24_VOLUME_NATIVE_DESC = 'h24_volume_native_desc'

    FLOOR_PRICE_NATIVE_ASC = 'floor_price_native_asc'

    FLOOR_PRICE_NATIVE_DESC = 'floor_price_native_desc'

    MARKET_CAP_NATIVE_ASC = 'market_cap_native_asc'

    MARKET_CAP_NATIVE_DESC = 'market_cap_native_desc'

    MARKET_CAP_USD_ASC = 'market_cap_usd_asc'

    MARKET_CAP_USD_DESC = 'market_cap_usd_desc'

