# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class DexPairFormatEnum(object):

    """Implementation of the 'dex_pair_format' enum.

    Attributes:
        CONTRACT_ADDRESS: The enum member of type str.
        SYMBOL: The enum member of type str.

    """
    CONTRACT_ADDRESS = 'contract_address'

    SYMBOL = 'symbol'

