# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PrecisionEnum(object):

    """Implementation of the 'precision' enum.

    Attributes:
        FULL: The enum member of type str.
        ENUM_0: The enum member of type str.
        ENUM_1: The enum member of type str.
        ENUM_2: The enum member of type str.
        ENUM_3: The enum member of type str.
        ENUM_4: The enum member of type str.
        ENUM_5: The enum member of type str.
        ENUM_6: The enum member of type str.
        ENUM_7: The enum member of type str.
        ENUM_8: The enum member of type str.
        ENUM_9: The enum member of type str.
        ENUM_10: The enum member of type str.
        ENUM_11: The enum member of type str.
        ENUM_12: The enum member of type str.
        ENUM_13: The enum member of type str.
        ENUM_14: The enum member of type str.
        ENUM_15: The enum member of type str.
        ENUM_16: The enum member of type str.
        ENUM_17: The enum member of type str.
        ENUM_18: The enum member of type str.

    """
    FULL = 'full'

    ENUM_0 = '0'

    ENUM_1 = '1'

    ENUM_2 = '2'

    ENUM_3 = '3'

    ENUM_4 = '4'

    ENUM_5 = '5'

    ENUM_6 = '6'

    ENUM_7 = '7'

    ENUM_8 = '8'

    ENUM_9 = '9'

    ENUM_10 = '10'

    ENUM_11 = '11'

    ENUM_12 = '12'

    ENUM_13 = '13'

    ENUM_14 = '14'

    ENUM_15 = '15'

    ENUM_16 = '16'

    ENUM_17 = '17'

    ENUM_18 = '18'

