# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class IncludeTokensEnum(object):

    """Implementation of the 'include_tokens' enum.

    Attributes:
        TOP: The enum member of type str.
        ALL: The enum member of type str.

    """
    TOP = 'top'

    ALL = 'all'

