# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class FilterEnum(object):

    """Implementation of the 'filter' enum.

    Attributes:
        NFT: The enum member of type str.

    """
    NFT = 'nft'

