# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OrderEnum(object):

    """Implementation of the 'order' enum.

    Attributes:
        MARKET_CAP_ASC: The enum member of type str.
        MARKET_CAP_DESC: The enum member of type str.
        VOLUME_ASC: The enum member of type str.
        VOLUME_DESC: The enum member of type str.
        ID_ASC: The enum member of type str.
        ID_DESC: The enum member of type str.

    """
    MARKET_CAP_ASC = 'market_cap_asc'

    MARKET_CAP_DESC = 'market_cap_desc'

    VOLUME_ASC = 'volume_asc'

    VOLUME_DESC = 'volume_desc'

    ID_ASC = 'id_asc'

    ID_DESC = 'id_desc'

