# -*- coding: utf-8 -*-

"""
coingeckopublicapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class DaysEnum(object):

    """Implementation of the 'days' enum.

    Attributes:
        ENUM_1: The enum member of type str.
        ENUM_7: The enum member of type str.
        ENUM_14: The enum member of type str.
        ENUM_30: The enum member of type str.
        ENUM_90: The enum member of type str.
        ENUM_180: The enum member of type str.
        ENUM_365: The enum member of type str.

    """
    ENUM_1 = '1'

    ENUM_7 = '7'

    ENUM_14 = '14'

    ENUM_30 = '30'

    ENUM_90 = '90'

    ENUM_180 = '180'

    ENUM_365 = '365'

